summaryrefslogtreecommitdiffstats
path: root/tdeui/kpanelextension.h
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2013-03-02 15:57:34 -0600
committerDarrell Anderson <humanreadable@yahoo.com>2013-03-02 15:57:34 -0600
commit7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f (patch)
treec76702a7f6310fbe9d437e347535422e836e94e9 /tdeui/kpanelextension.h
parenta2a38be7600e2a2c2b49c66902d912ca036a2c0f (diff)
parent27bbee9a5f9dcda53d8eb23863ee670ad1360e41 (diff)
downloadtdelibs-7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f.tar.gz
tdelibs-7c0b0c9dc9fcbe9c198925bdc7ee18ac6be49f4f.zip
Merge branch 'master' of http://scm.trinitydesktop.org/scm/git/tdelibs
Diffstat (limited to 'tdeui/kpanelextension.h')
-rw-r--r--tdeui/kpanelextension.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/tdeui/kpanelextension.h b/tdeui/kpanelextension.h
index fec6bd2ee..f97e85482 100644
--- a/tdeui/kpanelextension.h
+++ b/tdeui/kpanelextension.h
@@ -28,7 +28,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <tdelibs_export.h>
class TQPopupMenu;
-class KConfig;
+class TDEConfig;
class KPanelExtensionPrivate;
/**
@@ -56,7 +56,7 @@ class KPanelExtensionPrivate;
*
* \b X-TDE-UniqueExtension \n
*
- * Similar to KApplication and KUniqueApplication there are
+ * Similar to TDEApplication and KUniqueApplication there are
* two types of panel extensions. Use unique extensions when it makes no
* sence to run more than one instance of an extension in the panel. A
* good example for unique extensions is the taskbar extension. Use normal
@@ -80,7 +80,7 @@ class KPanelExtensionPrivate;
* {
* KPanelExtension* init(TQWidget *parent, const TQString& configFile)
* {
- * KGlobal::locale()->insertCatalogue("exampleextension");
+ * TDEGlobal::locale()->insertCatalogue("exampleextension");
* return new ExampleExtension(configFile, KPanelExtension::Normal,
* KPanelExtension::About | KPanelExtension::Help | KPanelExtension::Preferences,
* parent, "exampleextension");
@@ -139,7 +139,7 @@ public:
virtual TQSize sizeHint(Position /*p*/, TQSize maxsize) const { return maxsize; }
/**
* Always use this KConfig object to save/load your extensions configuration.
*
* For unique extensions this config object will write to a config file called
* \<extensionname\>rc in the users local KDE directory.
@@ -147,7 +147,7 @@ public:
* For normal extensions this config object will write to a instance specific config file
* called \<extensionname\>\<instanceid\>rc in the users local KDE directory.
**/
- KConfig* config() const { return _config; }
+ TDEConfig* config() const { return _config; }
/**
* @return Type indicating the extensions type.
@@ -334,7 +334,7 @@ private:
Type _type;
Position _position;
Alignment _alignment;
- KConfig* _config;
+ TDEConfig* _config;
int _actions;
protected:
virtual void virtual_hook( int id, void* data );
@@ -139,7 +139,7 @@ public:
virtual TQSize sizeHint(Position /*p*/, TQSize maxsize) const { return maxsize; }
/**
- * Always use this KConfig object to save/load your extensions configuration.
+ * Always use this TDEConfig object to save/load your extensions configuration.
*
* For unique extensions this config object will write to a config file called